@@ -102,7 +102,6 @@ use warnings FATAL => qw(all);
 use strict;
 use utf8;
 use Carp;
-use Data::Dump qw(dump);
 
 #-------------------------------------------------------------------------------
 # Our definition of nearness
@@ -1104,10 +1103,11 @@ $EXPORT_TAGS{all} = [@EXPORT, @EXPORT_OK];
  1.005 Sun 20 Dec 2015 - Still going!
  1.006 Sat 02 Jan 2016 - Euler's line divided into 6 equal pieces
  1.007 Sat 02 Jan 2016 - [rt.cpan.org #110849] Test suite fails with uselongdouble
+ 1.008 Sun 03 Jan 2016 - [rt.cpan.org #110849] Removed dump
 
 =cut
 
-$VERSION   = '1.007';
+$VERSION   = '1.008';
 
 =pod
 
